Crate muffy

Crate muffy 

Muffy

GitHub Action Codecov Crate Docker Pulls License

The static website validator.

Features

  • Recursive link checking of all pages in websites
  • Markup validation of HTML, SVG, and MathML documents
  • Checks of multiple websites with a single configuration file
  • Persistent response caching with configurable cache ages and stale-while-revalidate periods
  • Concurrency and rate limits, and retries with exponential backoff
  • robots.txt and sitemap support

Install

cargo install muffy

Usage

For the full usage, see muffy --help.

Check a set of websites

muffy

or

muffy check

Check a website

muffy check-site https://example.com

GitHub Action

job:
  steps:
    # After building and/or deploying your website.
    - uses: raviqqe/muffy@v0.4.1

See action.yaml for more details.

References

License

MIT

Structs

CacheConfig
A cache configuration.
ClockTimer
A wall-clock timer.
ConcurrencyConfig
A concurrency configuration.
Config
A validation configuration.
DocumentOutput
A document output.
DocumentParser
A document parser.
FjallCache
A cache backed by the Fjall database.
HttpClient
A full-featured HTTP client.
MarkupConfig
A markup validation configuration.
MemoryCache
An in-memory cache.
Metrics
Validation metrics.
MokaCache
An in-memory cache backed by moka.
RateLimitConfig
A rate limit configuration.
RateLimiter
A token bucket rate limiter.
RenderOptions
Rendering options.
ReqwestHttpClient
An HTTP client backed by reqwest.
RetryConfig
A retry configuration.
RetryDurationConfig
A retry duration configuration.
SchemeConfig
A scheme configuration.
SerializableConfig
A serializable configuration.
SiteConfig
A site configuration.
SiteRateLimitConfig
A site rate limit configuration.
SledCache
A cache backed by the Sled database.
StatusConfig
A status code configuration.
ValidationConfig
A validation configuration.
WebValidator
A web validator.

Enums

ConfigError
A configuration error.
Error
An error.
ItemError
An item error.
RenderFormat
A rendering format.

Constants

DEFAULT_ACCEPTED_SCHEMES
Default accepted URL schemes.
DEFAULT_ACCEPTED_STATUS_CODES
Default accepted HTTP status codes.
DEFAULT_MAX_REDIRECTS
A default number of maximum redirects.
DEFAULT_TIMEOUT
A default HTTP timeout.

Traits

BareHttpClient
A bare HTTP client.
GlobalCache
A global cache.
LocalCache
A local cache.

Functions

compile_config
Compiles a configuration.
default_concurrency
Returns a default concurrency.
read_config
Reads a configuration file recursively.
render_document
Renders a result of document validation.